#[non_exhaustive]pub struct GetCoinInfoResponse {
pub coin_type: Option<String>,
pub metadata: Option<CoinMetadata>,
pub treasury: Option<CoinTreasury>,
pub regulated_metadata: Option<RegulatedCoinMetadata>,
}Expand description
Response message for StateService.GetCoinInfo.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.coin_type: Option<String>Required. The coin type.
metadata: Option<CoinMetadata>This field will be populated with information about this coin
type’s 0x2::coin::CoinMetadata if it exists and has not been wrapped.
treasury: Option<CoinTreasury>This field will be populated with information about this coin
type’s 0x2::coin::TreasuryCap if it exists and has not been wrapped.
regulated_metadata: Option<RegulatedCoinMetadata>If this coin type is a regulated coin, this field will be
populated with information either from its Currency object
in the CoinRegistry, or from its 0x2::coin::RegulatedCoinMetadata
object for coins that have not been migrated to the CoinRegistry
If this coin is not known to be regulated, only the coin_regulated_state field will be populated.
Implementations
Sourceimpl GetCoinInfoResponse
impl GetCoinInfoResponse
pub const COIN_TYPE_FIELD: &'static MessageField
pub const METADATA_FIELD: &'static MessageField
pub const TREASURY_FIELD: &'static MessageField
pub const REGULATED_METADATA_FIELD: &'static MessageField
Sourceimpl GetCoinInfoResponse
impl GetCoinInfoResponse
Sourcepub fn with_coin_type<T: Into<String>>(self, field: T) -> Self
pub fn with_coin_type<T: Into<String>>(self, field: T) -> Self
Sets coin_type with the provided value.
Sourcepub fn with_metadata<T: Into<CoinMetadata>>(self, field: T) -> Self
pub fn with_metadata<T: Into<CoinMetadata>>(self, field: T) -> Self
Sets metadata with the provided value.
Sourcepub fn with_treasury<T: Into<CoinTreasury>>(self, field: T) -> Self
pub fn with_treasury<T: Into<CoinTreasury>>(self, field: T) -> Self
Sets treasury with the provided value.
Sourcepub fn with_regulated_metadata<T: Into<RegulatedCoinMetadata>>(
self,
field: T,
) -> Self
pub fn with_regulated_metadata<T: Into<RegulatedCoinMetadata>>( self, field: T, ) -> Self
Sets regulated_metadata with the provided value.